/**
 * 
 */
package com.example.listviewscrollstatus;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import android.content.Context;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.View.OnClickListener;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.CheckBox;
import android.widget.ImageButton;
import android.widget.ImageView;
import android.widget.TextView;

/**
 * @Description
 * @author act262
 * @version 1.0
 * @since 2014-6-21 下午5:58:38
 * 
 */
public final class ListContentAdapter extends BaseAdapter {
	private Context mContext;
	private List<Map<String, Object>> mList;
	private ViewHolder viewHolder = null;

	// 用户记住CheckBox的状态
	private Map<Integer, Boolean> selectStaus;

	public ListContentAdapter(Context context, List<Map<String, Object>> list) {
		this.mContext = context;
		this.mList = list;

		selectStaus = new HashMap<Integer, Boolean>();
		// 初始状态全部为不选中状态，故设为false
		for (int i = 0; i < list.size(); i++) {
			// 使用当前的位置作为key，boolean作为value
			selectStaus.put(i, false);
		}
	}

	// 在绘制ListView时调用该方法
	@Override
	public int getCount() {
		return mList.size();
	}

	// 返回指定位置的Item
	@Override
	public Object getItem(int position) {
		return mList.get(position);
	}

	// 不指定id,一般为当前的位置
	@Override
	public long getItemId(int position) {
		return position;
	}

	/**
	 * 自定义Adapter的最重要的方法: 使用ViewHolder作为一个缓存的对象，可以减少findViewById();
	 * 假设一个ListView的空间一次加载10个item，也就是有对应的View
	 * 容器ConvertView10个，每次使viewHolder指向该ConvertView,第一个加载时convertView
	 * 为null，以后就不是null了； 当滚动ListView时，convertView不为null，从viewholder获取到缓存的视图数据,
	 */
	@Override
	public View getView(final int position, View convertView, ViewGroup parent) {

		if (null == convertView) {
			convertView = LayoutInflater.from(mContext).inflate(R.layout.view_listview_item, null);

			viewHolder = new ViewHolder();
			viewHolder.iconView = (ImageView) convertView.findViewById(R.id.iv_icon);
			viewHolder.titleView = (TextView) convertView.findViewById(R.id.tv_title);
			viewHolder.selectView = (CheckBox) convertView.findViewById(R.id.cb_select);
			viewHolder.setButton = (ImageButton) convertView.findViewById(R.id.ib_set);

			viewHolder.setButton.setOnClickListener(new OnClickListener() {

				@Override
				public void onClick(View v) {
					Log.i("viewHolder.setButton", " click " + position);
				}
			});

			convertView.setTag(viewHolder);
		} else {
			viewHolder = (ViewHolder) convertView.getTag();
		}

		viewHolder.iconView.setImageResource((Integer) mList.get(position).get("icon"));
		viewHolder.titleView.setText((CharSequence) mList.get(position).get("title"));

		final CheckBox checkBox = viewHolder.selectView;
		checkBox.setChecked(selectStaus.get(position));
		checkBox.setOnClickListener(new OnClickListener() {
			public void onClick(View v) {
				Log.i("checkbox onclick", "click :" + position);
				selectStaus.put(position, checkBox.isChecked());
			}
		});

		//监听器只能放在这外面才行
		viewHolder.setButton.setOnClickListener(new OnClickListener() {

			@Override
			public void onClick(View v) {
				Log.d("viewHolder.setButton", " click " + position);
			}
		});

		return convertView;
	}

	private final class ViewHolder {
		ImageView iconView;
		TextView titleView;
		CheckBox selectView;
		ImageButton setButton;
	}

}